<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Slovenčina [sk]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'spip-dev@rezo.net',

	// A
	'access_interface_graphique' => 'Späť na úplné grafické rozhranie',
	'access_mode_texte' => 'Zobraziť zjednodušené textové rozhranie',
	'admin_debug' => 'Ladiť',
	'admin_modifier_article' => 'Upraviť tento článok',
	'admin_modifier_auteur' => 'Upraviť tohto autora',
	'admin_modifier_breve' => 'Upraviť túto novinku',
	'admin_modifier_mot' => 'Upraviť toto kľúčové slovo',
	'admin_modifier_rubrique' => 'Upraviť túto rubriku',
	'admin_recalculer' => 'Obnoviť túto stránku',
	'afficher_calendrier' => 'Zobraziť kalendár',
	'afficher_trad' => 'Zobraziť preklady',
	'alerte_maj_impossible' => '<b>Upozornenie!</b> Nepodarilo sa aktualizovať databázu SQL na verziu @version@. Môže to byť kvôli problému s povoleniami k databáze. Prosím, kontaktujte svojho poskytovateľa internetových služieb.',
	'alerte_modif_info_concourante' => 'POZOR: Tento údaj bol zmenený inde. Jeho aktuálna hodnota je:',
	'analyse_xml' => 'Analýza XML',
	'annuler' => 'Zrušiť',
	'antispam_champ_vide' => 'Toto pole, prosím, nevypĺňajte:',
	'articles_recents' => 'Najnovšie články',
	'avis_1_erreur_saisie' => 'Vo vašom zadaní je 1 chyba, skontrolujte si údaje.', # MODIF
	'avis_archive_incorrect' => 'archívny súbor nie je platný súbor SPIPu',
	'avis_archive_invalide' => 'archívny súbor nie je platný',
	'avis_attention' => 'POZOR!',
	'avis_champ_incorrect_type_objet' => 'Neplatný názov poľa @name@ pre objekt typu @type@',
	'avis_colonne_inexistante' => 'Stĺpec @col@ neexistuje',
	'avis_erreur' => 'Chyba: pozri nižšie',
	'avis_erreur_connexion' => 'Chyba pripojenia',
	'avis_erreur_cookie' => 'problém s cookie',
	'avis_erreur_fonction_contexte' => 'Chyba pri programovaní. Túto funkciu nemožno volať v takejto situácii.',
	'avis_erreur_mysql' => 'Chyba SQL',
	'avis_erreur_sauvegarde' => 'Chyba v zálohe (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Problém pri vstupe do súkromnej zóny',
	'avis_nb_erreurs_saisie' => 'Vo vašom zadaní je @nb@ chýb, skontrolujte si údaje.',

	// B
	'barre_a_accent_grave' => 'Vložiť veľké A s opačným dĺžňom',
	'barre_aide' => 'Na zmenu vzhľadu používajte klávesové skratky',
	'barre_e_accent_aigu' => 'Vložiť veľké dlhé E ',
	'barre_eo' => 'Vložiť zložku eo',
	'barre_eo_maj' => 'Vložiť veľkú zložku EO',
	'barre_euro' => 'Vložiť symbol €',
	'barre_gras' => 'Zmeniť na {{tučné}}',
	'barre_guillemets' => 'Dať do "dvojitých úvodzoviek"',
	'barre_guillemets_simples' => 'Dať do ‘jednoduchých úvodzoviek’',
	'barre_intertitre' => 'Zmeniť na {{{medzititulok}}}',
	'barre_italic' => 'Zmeniť na {kurzívu}',
	'barre_lien' => 'Zmeniť na [odkaz -> http://...]',
	'barre_lien_input' => 'Prosím, zadajte adresu odkazu. Môžete použiť externú adresu (http://www.mojastranka.sk) alebo odkážte na iný článok na tejto stránke tak, že zadáte jeho číslo.',
	'barre_note' => 'Zmeniť na [[poznámku pod čiarou]]',
	'barre_paragraphe' => 'Urobiť odsek',
	'barre_quote' => '<quote>Citovať príspevok</quote>',
	'bouton_changer' => 'Upraviť',
	'bouton_chercher' => 'Vyhľadať',
	'bouton_choisir' => 'Vybrať',
	'bouton_deplacer' => 'Presunúť',
	'bouton_download' => 'Stiahnuť',
	'bouton_enregistrer' => 'Uložiť',
	'bouton_radio_desactiver_messagerie_interne' => 'Deaktivovať interný odkazovač',
	'bouton_radio_envoi_annonces' => 'Posielať oznamy z redakcie',
	'bouton_radio_non_envoi_annonces' => 'Neposielať žiadne oznamy',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Neposielať zoznam najnovších správ',
	'bouton_recharger_page' => 'obnoviť túto stránku',
	'bouton_telecharger' => 'Stiahnuť',
	'bouton_upload' => 'Nahrať',
	'bouton_valider' => 'Potvrdiť',

	// C
	'cal_apresmidi' => 'poobede (p.m.)',
	'cal_jour_entier' => 'celý deň',
	'cal_matin' => 'doobeda (a.m.)',
	'cal_par_jour' => 'Kalendár na deň',
	'cal_par_mois' => 'Kalendár na mesiac',
	'cal_par_semaine' => 'Kalendár na týždeň',
	'choix_couleur_interface' => 'farba ',
	'choix_interface' => 'výber rozhrania',
	'colonne' => 'Stĺpec',
	'confirm_changer_statut' => 'Pozor, požiadali ste o zmenu stavu tohto prvku. Chcete pokračovať?',
	'correcte' => 'správne',

	// D
	'date_aujourdhui' => 'dnes',
	'date_avant_jc' => 'p. K.',
	'date_dans' => 'o @delai@',
	'date_de_mois_1' => '@j@ januára',
	'date_de_mois_10' => '@j@ októbra',
	'date_de_mois_11' => '@j@ novembra',
	'date_de_mois_12' => '@j@ decembra',
	'date_de_mois_2' => '@j@ februára',
	'date_de_mois_3' => '@j@ marca',
	'date_de_mois_4' => '@j@ apríla',
	'date_de_mois_5' => '@j@ mája',
	'date_de_mois_6' => '@j@ júna',
	'date_de_mois_7' => '@j@ júla',
	'date_de_mois_8' => '@j@ augusta',
	'date_de_mois_9' => '@j@ septembra',
	'date_demain' => 'zajtra',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_heures_minutes_court' => '@h@h:@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ o @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ o @heure_debut@ do @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ o @heure_debut@@dtabbr@ do @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => '@date@ @nomjour@',
	'date_fmt_periode' => 'Od @date_debut@ do @date_fin@',
	'date_fmt_periode_abbr' => 'Od @dtart@@date_debut@@dtabbr@ do @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Od',
	'date_fmt_periode_to' => 'do',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'hodinami',
	'date_hier' => 'včera',
	'date_il_y_a' => 'pred @delai@',
	'date_jnum1' => '1.',
	'date_jnum10' => '10.',
	'date_jnum11' => '11.',
	'date_jnum12' => '12.',
	'date_jnum13' => '13.',
	'date_jnum14' => '14.',
	'date_jnum15' => '15.',
	'date_jnum16' => '16.',
	'date_jnum17' => '17.',
	'date_jnum18' => '18.',
	'date_jnum19' => '19.',
	'date_jnum2' => '2.',
	'date_jnum20' => '20.',
	'date_jnum21' => '21.',
	'date_jnum22' => '22.',
	'date_jnum23' => '23.',
	'date_jnum24' => '24.',
	'date_jnum25' => '25.',
	'date_jnum26' => '26.',
	'date_jnum27' => '27.',
	'date_jnum28' => '28.',
	'date_jnum29' => '29.',
	'date_jnum3' => '3.',
	'date_jnum30' => '30.',
	'date_jnum31' => '31.',
	'date_jnum4' => '4.',
	'date_jnum5' => '5.',
	'date_jnum6' => '6.',
	'date_jnum7' => '7.',
	'date_jnum8' => '8.',
	'date_jnum9' => '9.',
	'date_jour_1' => 'nedeľa',
	'date_jour_1_abbr' => 'ned.',
	'date_jour_1_initiale' => 'n.',
	'date_jour_2' => 'pondelok',
	'date_jour_2_abbr' => 'pon.',
	'date_jour_2_initiale' => 'p.',
	'date_jour_3' => 'utorok',
	'date_jour_3_abbr' => 'uto.',
	'date_jour_3_initiale' => 'u.',
	'date_jour_4' => 'streda',
	'date_jour_4_abbr' => 'str.',
	'date_jour_4_initiale' => 's.',
	'date_jour_5' => 'štvrtok',
	'date_jour_5_abbr' => 'štv.',
	'date_jour_5_initiale' => 'š.',
	'date_jour_6' => 'piatok',
	'date_jour_6_abbr' => 'pia.',
	'date_jour_6_initiale' => 'p.',
	'date_jour_7' => 'sobota',
	'date_jour_7_abbr' => 'sob.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'dňami',
	'date_minutes' => 'minútami',
	'date_mois' => 'mesiacov',
	'date_mois_1' => 'január',
	'date_mois_10' => 'október',
	'date_mois_10_abbr' => 'okt.',
	'date_mois_11' => 'november',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'december',
	'date_mois_12_abbr' => 'dec.',
	'date_mois_1_abbr' => 'jan.',
	'date_mois_2' => 'február',
	'date_mois_2_abbr' => 'feb.',
	'date_mois_3' => 'marec',
	'date_mois_3_abbr' => 'mar.',
	'date_mois_4' => 'apríl',
	'date_mois_4_abbr' => 'apr.',
	'date_mois_5' => 'máj',
	'date_mois_5_abbr' => 'máj',
	'date_mois_6' => 'jún',
	'date_mois_6_abbr' => 'jún',
	'date_mois_7' => 'júl',
	'date_mois_7_abbr' => 'júl',
	'date_mois_8' => 'august',
	'date_mois_8_abbr' => 'aug.',
	'date_mois_9' => 'september',
	'date_mois_9_abbr' => 'sept.',
	'date_saison_1' => 'zima',
	'date_saison_2' => 'jar',
	'date_saison_3' => 'leto',
	'date_saison_4' => 'jeseň',
	'date_secondes' => 'sekundami',
	'date_semaines' => 'týždňami',
	'date_un_mois' => 'mesiacom',
	'date_une_heure' => 'hodinou',
	'date_une_minute' => 'minútou',
	'date_une_seconde' => 'sekundou',
	'date_une_semaine' => 'týždňom',
	'dirs_commencer' => ' aby sa inštalácia mohla naozaj začať',
	'dirs_preliminaire' => 'Predpríprava: <b>Nastavenie prístupových práv</b>',
	'dirs_probleme_droits' => 'Problém s prístupovými právami',
	'dirs_repertoires_absents' => '<p><b>Nenašli sa tieto priečinky: </b></p><ul>@bad_dirs@.</ul>
  <p>Je pravdepodobné, že sa to stalo kvôli nesprávnemu použitiu malých a veľkých písmen v ich názvoch.
  Prosím, skontrolujte, či veľké a malé písmená v názvoch týchto priečinkoch sú rovnaké ako vyššie.
  Ak to tak nie je, premenujte priečinky pomocou FTP klienta.</p>
  <p>Keď to urobíte, môžete ',
	'dirs_repertoires_suivants' => '<p><b>Tieto priečinky nemajú povolenie na zápis: </b></p><ul>@bad_dirs@</ul>
<p>Aby sa to zmenilo, použite svojho FTP klienta na nastavenie prístupových práv pre každý
 z týchto priečinkov. Postup je podrobne opísaný v sprievodcovi inštaláciou.</p>
  <p>Keď to urobíte, môžete ',
	'double_occurrence' => 'Dva výskyty @balise@',

	// E
	'en_cours' => 'Spracúva sa',
	'envoi_via_le_site' => 'Poslané cez stránku',
	'erreur' => 'Chyba',
	'erreur_balise_non_fermee' => 'posledný tag nie je uzavretý:',
	'erreur_technique_ajaxform' => 'Ups! Neočakávaná chyba zabránila odoslaniu formulára. Môžete to skúsiť znova.',
	'erreur_technique_enregistrement_champs' => 'Technická chyba zabránila správnemu uloženiu poľa @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Uloženiu zabránila technická chyba.',
	'erreur_texte' => 'Chyba (-y)',
	'etape' => 'Etapa',

	// F
	'fichier_introuvable' => 'Súbor @fichier@ sa nenašiel',
	'form_auteur_confirmation' => 'Prosím, potvrďte svoju e-mailovú adresu',
	'form_auteur_email_modifie' => 'Vaša e-mailová adresa sa zmenila.',
	'form_auteur_envoi_mail_confirmation' => 'Na adresu @email@ bol odoslaný potvrdzovací e-mail. Musíte navštíviť stránku uvedenú v správe a potvrdiť tak svoju e-mailovú adresu.',
	'form_auteur_mail_confirmation' => 'Dobrý deň,

požiadali ste o zmenu svojej e-mailovej adresy.
Na potvrdenie svojej novej adresy musíte kliknúť
na adresu nižšie (inak bude vaša požiadavka ignorovaná):

    @url@
',
	'form_deja_inscrit' => 'Už ste sa zaregistrovali.',
	'form_email_non_valide' => 'Vaša e-mailová adresa nie je platná.',
	'form_forum_access_refuse' => 'Na túto stránku už viac nemáte prístup.',
	'form_forum_bonjour' => 'Dobrý deň @nom@,',
	'form_forum_confirmer_email' => 'Ak chcete potvrdiť svoju e-mailovú adresu, kliknite na tento odkaz: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Táto e-mailová adresa je už zaregistrovaná, môžete zadať svoje heslo ako zvyčajne.',
	'form_forum_identifiant_mail' => 'Váš nový prihlasovací údaj sme vám práve poslali e-mailom.',
	'form_forum_identifiants' => 'Osobné prihlasovacie údaje',
	'form_forum_indiquer_nom_email' => 'Sem zadajte svoje meno a e-mailovú adresu. Čoskoro dostanete e-mailom svoj osobný prihlasovací údaj.',
	'form_forum_login' => 'Prihlasovacie meno:',
	'form_forum_message_auto' => '(toto je automatická správa)',
	'form_forum_pass' => 'Heslo:',
	'form_forum_probleme_mail' => 'Problém s mejlom: prihlasovací údaj sa nepodarilo odoslať.',
	'form_forum_voici1' => 'Tu sú vaše prihlasovacie údaje. Teraz sa môžete zúčastňovať na dianí na stránke
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Tu sú vaše prihlasovacie údaje na posielanie údajov na
stránku "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Prosím, zadajte svoju e-mailovú adresu.',
	'form_indiquer_nom' => 'Zadajte, prosím, svoje meno.',
	'form_indiquer_nom_site' => 'Prosím, zadajte názov svojej stránky.',
	'form_pet_deja_enregistre' => 'Táto stránka je už zaregistrovaná',
	'form_pet_signature_pasprise' => 'Váš podpis bol ignorovaný.',
	'form_prop_confirmer_envoi' => 'Potvrdiť odoslanie',
	'form_prop_description' => 'Opis/komentár',
	'form_prop_enregistre' => 'Váš návrh bol uložený. Online sa zobrazí po schválení administrátorom tejto stránky.',
	'form_prop_envoyer' => 'Poslať správu',
	'form_prop_indiquer_email' => 'Prosím, zadajte platnú e-mailovú adresu',
	'form_prop_indiquer_nom_site' => 'Prosím, zadajte názov stránky.',
	'form_prop_indiquer_sujet' => 'Prosím, zadajte predmet',
	'form_prop_message_envoye' => 'Správa odoslaná',
	'form_prop_non_enregistre' => 'Váš návrh nebol uložený.',
	'form_prop_sujet' => 'Predmet',
	'form_prop_url_site' => 'Adresa stránky',
	'forum_non_inscrit' => 'Buď ste sa nezaregistrovali, alebo sú adresa či heslo nesprávne.',
	'forum_par_auteur' => 'napísal(a) @auteur@',
	'forum_titre_erreur' => 'Chyba...',

	// I
	'ical_texte_rss_articles' => 'Backendový súbor tejto stránky pre články nájdete na adrese:',
	'ical_texte_rss_articles2' => 'Môžete získať backendové súbory aj pre jednotlivé rubriky, a to na stránke:',
	'ical_texte_rss_breves' => 'Naviac tu je súbor, ktorý obsahuje novinky zo stránky. Ak si zvolíte číslo rubriky, môžete dostávať novinky výlučne z príslušnej rubriky.',
	'icone_a_suivre' => 'Poznámkový blok',
	'icone_admin_site' => 'Administrácia stránky',
	'icone_agenda' => 'Kalendár',
	'icone_aide_ligne' => 'Pomocník',
	'icone_articles' => 'Články',
	'icone_auteurs' => 'Autori',
	'icone_brouteur' => 'Rýchla navigácia',
	'icone_configuration_site' => 'Konfigurácia',
	'icone_configurer_site' => 'Nastavte si stránku',
	'icone_creer_nouvel_auteur' => 'Zapísať nového autora',
	'icone_creer_rubrique' => 'Vytvoriť rubriku',
	'icone_creer_sous_rubrique' => 'Vytvoriť podrubriku',
	'icone_deconnecter' => 'Odhlásiť sa',
	'icone_discussions' => 'Diskusie',
	'icone_doc_rubrique' => 'Dokumenty v rubrikách',
	'icone_ecrire_article' => 'Napísať nový článok',
	'icone_edition_site' => 'Upraviť stránku',
	'icone_gestion_langues' => 'Administrácia jazykov',
	'icone_informations_personnelles' => 'Osobné údaje',
	'icone_interface_complet' => 'Úplné rozhranie',
	'icone_interface_simple' => 'Zjednodušené rozhranie',
	'icone_maintenance_site' => 'Údržba stránky',
	'icone_messagerie_personnelle' => 'Súkromný odkazovač',
	'icone_repartition_debut' => 'Zobraziť distribúciu od začiatku',
	'icone_rubriques' => 'Rubriky',
	'icone_sauver_site' => 'Zálohovať stránku',
	'icone_site_entier' => 'Celú stránku',
	'icone_sites_references' => 'Stránky, na ktoré odkazujete',
	'icone_statistiques' => 'Štatistika stránky',
	'icone_suivi_activite' => 'Sledovanie aktivity stránky',
	'icone_suivi_actualite' => 'Štatistika stránky',
	'icone_suivi_pettions' => 'Sledovať/riadiť petície',
	'icone_suivi_revisions' => 'Opravy článku',
	'icone_supprimer_document' => 'Odstrániť tento dokument',
	'icone_supprimer_image' => 'Odstrániť tento obrázok',
	'icone_tous_articles' => 'Všetky vaše články',
	'icone_tous_auteur' => 'Všetci autori',
	'icone_tous_visiteur' => 'Všetci návštevníci',
	'icone_visiter_site' => 'Zobraziť verejne prístupnú stránku',
	'icone_voir_en_ligne' => 'Zobraziť online',
	'img_indisponible' => 'Obrázok je nedostupný',
	'impossible' => 'Nedá sa',
	'info_a_suivre' => 'POZNÁMKOVÝ BLOK»',
	'info_acces_interdit' => 'Prístup zakázaný',
	'info_acces_refuse' => 'Prístup zamietnutý',
	'info_action' => 'Akcia: @action@',
	'info_administrer_rubriques' => 'Môžete riadiť túto rubriku a všetky jej podrubriky',
	'info_adresse_non_indiquee' => 'Neuviedli ste adresu, ktorú treba otestovať!',
	'info_aide' => 'POMOCNÍK:',
	'info_ajouter_mot' => 'Pridať toto kľúčové slovo',
	'info_annonce' => 'OZNAM',
	'info_annonces_generales' => 'Všeobecné oznamy:',
	'info_article_propose' => 'Článok odoslaný',
	'info_article_publie' => 'Článok publikovaný',
	'info_article_redaction' => 'Článok sa upravuje',
	'info_article_refuse' => 'Článok odmietnutý ',
	'info_article_supprime' => 'Článok odstránený',
	'info_articles' => 'Články',
	'info_articles_a_valider' => 'Články čakajúce na schválenie',
	'info_articles_nb' => '@nb@ článkov',
	'info_articles_proposes' => 'Odoslané články',
	'info_articles_un' => '1 článok',
	'info_auteurs_nombre' => 'Autor(i):',
	'info_authentification_ftp' => 'Prihlásenie (cez FTP).',
	'info_breves_2' => 'novinky',
	'info_breves_nb' => '@nb@ noviniek',
	'info_breves_un' => '1 novinka',
	'info_connexion_refusee' => 'Pripojenie zamietnuté',
	'info_contact_developpeur' => 'Prosím, kontaktujte vývojára.',
	'info_contenance' => 'Táto stránka obsahuje:',
	'info_contribution' => 'príspevky',
	'info_copyright' => '@spip@ je slobodný softvér distribuovaný @lien_gpl@',
	'info_copyright_doc' => 'viac informácií nájdete na stránke <a href="@spipnet@">@spipnet_affiche@.</a>',
	'info_copyright_gpl' => 's licenciou GPL.',
	'info_cours_edition' => 'Spracúva sa',
	'info_creer_repertoire' => 'Prosím, vytvorte súbor alebo priečinok s názvom:',
	'info_creer_repertoire_2' => 'v podpriečinku <b>@repertoire@</b>, potom',
	'info_creer_vignette' => 'automatické vytváranie miniatúr',
	'info_creerdansrubrique_non_autorise' => 'Na vytváranie obsahu tejto rubriky nemáte dostatočné práva.',
	'info_deplier' => 'Rozložiť',
	'info_descriptif_nombre' => 'Opis(y):',
	'info_description' => 'Opis:',
	'info_description_2' => 'Opis:',
	'info_dimension' => 'Veľkosť:',
	'info_documents_nb' => '@nb@ dokumentov',
	'info_documents_un' => '1 dokument',
	'info_ecire_message_prive' => 'Napísať súkromnú správu',
	'info_email_invalide' => 'Neplatná e-mailová adresa.',
	'info_en_cours_validation' => 'Vaše články, ktoré sa upravujú',
	'info_en_ligne' => 'Momentálne online:',
	'info_envoyer_message_prive' => 'Poslať súkromnú správu tomuto autorovi',
	'info_erreur_requete' => 'Chyba v požiadavke:',
	'info_erreur_squelette2' => 'Žiadna dostupná šablóna <b>@fichier@</b>...',
	'info_erreur_systeme' => 'Chyba systému (ch. č. @errsys@)',
	'info_erreur_systeme2' => 'Buď je plný pevný disk, alebo je poškodený databáza.<br />
<span style="color:red;">Poskúste sa <a href=\'@script@\'>opraviť databázu,</a> alebo kontaktujte poskytovateľa služby.</span>',
	'info_fini' => 'Hotovo!',
	'info_format_image' => 'Formát obrázkov, ktorý sa použije na vytváranie miniatúr: @gd_formats@.',
	'info_format_non_defini' => 'nedefinovaný formát',
	'info_grand_ecran' => 'Veľká obrazovka',
	'info_image_aide' => 'POMOCNÍK',
	'info_image_process_titre' => 'Ako vytvárať miniatúry',
	'info_impossible_lire_page' => '<b>Chyba!</b> Stránka <tt><html>@test_proxy@</html></tt> sa nedá zobraziť cez proxy',
	'info_installation_systeme_publication' => 'Inštaluje sa publikačný systém...',
	'info_installer_documents' => 'Všetky dokumenty v priečinku @upload@ si môžete nainštalovať automaticky.',
	'info_installer_ftp' => 'Ako administrátor môžete (cez FTP) nainštalovať súbory do priečinka @upload@, aby ste ich potom mohli vyberať priamo odtiaľ.',
	'info_installer_images' => 'Môžete si nainštalovať obrázky formátov JPEG, GIF a PNG.',
	'info_installer_images_dossier' => 'Obrázky nainštalujte do priečinka @upload@, ak ich odtiaľ chcete vyberať.',
	'info_interface_complete' => 'Úplné rozhranie',
	'info_interface_simple' => 'Zjednodušené rozhranie',
	'info_joindre_document_article' => 'K svojmu článku môžete pripojiť tieto typy dokumentov',
	'info_joindre_document_rubrique' => 'Do tejto rubriky môžete pridávať dokumenty týchto typov',
	'info_joindre_documents_article' => 'K svojmu článku môžete pripojiť dokumenty týchto typov:',
	'info_l_article' => 'článok',
	'info_la_breve' => 'novinka',
	'info_la_rubrique' => 'rubrika',
	'info_langue_principale' => 'Hlavný jazyk stránky',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixelov',
	'info_les_auteurs_1' => 'napísal(a) @les_auteurs@',
	'info_logo_format_interdit' => 'Povolené sú len logá vo formátoch @formats@.',
	'info_logo_max_poids' => 'Logá musia mať menej ako @maxi@ (tento súbor má @actuel@).',
	'info_mail_fournisseur' => 'you@mailservice.com',
	'info_message_2' => 'SPRÁVA ',
	'info_message_supprime' => 'ODKAZ ZMAZANÝ',
	'info_messages_nb' => '@nb@ správ',
	'info_messages_un' => '1 správa',
	'info_mise_en_ligne' => 'Uverejnené dňa:',
	'info_modification_parametres_securite' => 'menia sa parametre zabezpečenia',
	'info_mois_courant' => 'Počas mesiaca:',
	'info_mot_cle_ajoute' => 'Toto kľúčové slovo bolo pridané k',
	'info_multi_herit' => 'Predvolený jazyk',
	'info_multi_langues_soulignees' => '<u>Podčiarknuté jazyky</u> poskytujú preklad všetkých alebo takmer všetkých textov rozhrania. Ak si vyberiete niektorý z týchto jazykov, mnohé prvky verejne prístupnej stránky (dátumy, formuláre) sa preložia automaticky. Ak si vyberiete niektorý z jazykov, ktoré nie sú podčiarknuté, tieto prvky sa zobrazia v hlavnom jazyku stránky.',
	'info_multilinguisme' => 'Viacjazyčnosť',
	'info_nom_non_utilisateurs_connectes' => 'Vaše meno sa nezobrazuje v zozname používateľov online.',
	'info_nom_utilisateurs_connectes' => 'Vaše meno sa zobrazuje v zozname používateľov online.',
	'info_nombre_en_ligne' => 'Prihlásení:',
	'info_non_resultat' => 'Žiadne výsledky pre reťazec "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Nepoužívate súkromný odkazovať na tejto stránke.',
	'info_nouveau_message' => 'MÁTE NOVÚ SPRÁVU',
	'info_nouveaux_messages' => 'MÁTE @total_messages@ NOVÝCH SPRÁV',
	'info_numero_abbreviation' => 'č.',
	'info_obligatoire' => 'Tento údaj je povinný',
	'info_pense_bete' => 'PRIPOMIENKA',
	'info_petit_ecran' => 'Malá obrazovka',
	'info_petition_close' => 'Petícia skončená',
	'info_pixels' => 'pixelov',
	'info_plusieurs_mots_trouves' => 'Pre reťazec "@cherche_mot@" sa našlo niekoľko kľúčových slov:',
	'info_portfolio_automatique' => 'Automatické portfólio:',
	'info_premier_resultat' => '[Prvých @debut_limit@ výsledkov z(o) @total@]',
	'info_premier_resultat_sur' => '[Prvých @debut_limit@ výsledkov z(o) @total@]',
	'info_propose_1' => '[@nom_site_spip@] Odoslané: @titre@',
	'info_propose_2' => 'Článok odoslaný
---------------',
	'info_propose_3' => 'Článok „@titre@“ bol odoslaný na publikovanie.',
	'info_propose_4' => 'Môžete si ho prezrieť a povedať svoj názor',
	'info_propose_5' => 'v príslušnom diskusnom fóre. Je dostupný tu:',
	'info_publie_01' => 'Článok "@titre@" schválil(a) @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLIKOVANÉ: @titre@',
	'info_publie_2' => 'Článok publikovaný
------------------',
	'info_rechercher' => 'Hľadať',
	'info_rechercher_02' => 'Hľadať:',
	'info_remplacer_vignette' => 'Nahradiť predvolenú miniatúru vlastným logom:',
	'info_rubriques_nb' => '@nb@ rubrík',
	'info_rubriques_un' => '1 rubrika',
	'info_sans_titre_2' => 'bez názvu',
	'info_selectionner_fichier' => 'Môžete vybrať súbor z priečinka @upload@',
	'info_selectionner_fichier_2' => 'Vyberte súbor:',
	'info_sites_nb' => '@nb@ stránok',
	'info_sites_un' => '1 stránka',
	'info_supprimer_vignette' => 'Odstrániť miniatúru',
	'info_symbole_bleu' => '<b>Modrá</b> označuje <b>pripo­­mien­ku,</b> čiže odkaz pre vašu osobnú potrebu.',
	'info_symbole_jaune' => '<b>Žltá</b> označuje <b>oznam všetkým redaktorom:</b> môžu ho upravovať všetci administrátori a uvidia ho všetci redaktori.',
	'info_symbole_vert' => ' <b>Zelená</b> označuje <b>správy, ktoré ste si vymenili s ostatnými používateľmi</b> stránky.',
	'info_telecharger_nouveau_logo' => 'Nahrať nové logo:',
	'info_telecharger_ordinateur' => 'Nahrať z vášho počítača:',
	'info_tous_resultats_enregistres' => '[všetky výsledky sa ukladajú]',
	'info_tout_afficher' => 'Zobraziť všetko',
	'info_travaux_texte' => 'Táto stránka ešte nie je nastavená. Prosím, vráťte sa sem neskôr.',
	'info_travaux_titre' => 'Stránka sa rekonštruuje',
	'info_trop_resultat' => 'Priveľa nájdených položiek pre "@cherche_mot@"; prosím, upresnite svoje vyhľadávanie.',
	'info_utilisation_messagerie_interne' => 'Používate interný odkazovač tejto stránky.',
	'info_valider_lien' => 'Preveriť tento odkaz',
	'info_verifier_image' => ', prosím, uistite sa, že vaše obrázky boli premiestnené správne.',
	'info_vignette_defaut' => 'Predvolená miniatúra',
	'info_vignette_personnalisee' => 'Vlastná miniatúra',
	'info_visite' => 'návštevy:',
	'info_vos_rendez_vous' => 'Vaše stretnutia v budúcnosti',
	'infos_vos_pense_bete' => 'Vaše pripomienky',

	// L
	'label_ajout_id_rapide' => 'Rýchlo pridať',
	'label_poids_fichier' => 'Veľkosť',
	'lien_afficher_icones_seuls' => 'Zobraziť iba ikonky',
	'lien_afficher_texte_icones' => 'Zobraziť ikonky a text',
	'lien_afficher_texte_seul' => 'Zobraziť iba text',
	'lien_liberer' => 'Odstrániť',
	'lien_liberer_tous' => 'Odstrániť všetky',
	'lien_nouvea_pense_bete' => 'NOVÁ PRIPOMIENKA',
	'lien_nouveau_message' => 'NOVÁ SPRÁVA',
	'lien_nouvelle_annonce' => 'NOVÝ OZNAM',
	'lien_petitions' => 'PETÍCIA',
	'lien_popularite' => 'popularita: @popularite@%',
	'lien_racine_site' => 'KOREŇOVÝ ADRESÁR STRÁNKY',
	'lien_reessayer' => 'skúste to znova',
	'lien_repondre_message' => 'Odpovedať na túto správu',
	'lien_supprimer' => 'odstrániť',
	'lien_tout_afficher' => 'Zobraziť všetko',
	'lien_visite_site' => 'navštíviť túto stránku',
	'lien_visites' => '@visites@ návštev',
	'lien_voir_auteur' => 'Pozrieť tohto autora',
	'ligne' => 'Riadok',
	'login' => 'Prihlásenie',
	'login_acces_prive' => 'prístup do súkromnej zóny',
	'login_autre_identifiant' => 'prihlásiť sa pod inou identitou',
	'login_cookie_accepte' => 'Prosím, nastavte svoj prehliadač tak, aby ich z tejto stránky prijímal.',
	'login_cookie_oblige' => 'Kvôli bezpečnej identifikácii musí váš prehliadač prijímať cookies.',
	'login_deconnexion_ok' => 'Odhlásenie v poriadku.',
	'login_erreur_pass' => 'Chyba hesla.',
	'login_espace_prive' => 'súkromná zóna',
	'login_identifiant_inconnu' => 'Identifikátor "@login@" nie je známy',
	'login_login' => 'Prihlasovacie meno:',
	'login_login2' => 'Prihlasovacie meno alebo e-mailová adresa:',
	'login_login_pass_incorrect' => '(Nesprávne používateľské meno alebo heslo).',
	'login_motpasseoublie' => 'Zabudli ste heslo?',
	'login_non_securise' => 'Pozor: tento formulár nie je zabezpečený.
   Ak nechcete, aby bolo vaše heslo vystavené
   riziku odchytenia na sieti, prosím, aktivujte si Javascript
   v prehliadači a',
	'login_nouvelle_tentative' => 'Nový pokus',
	'login_par_ici' => 'Vy ste zaregistrovaný. Tadiaľ.',
	'login_pass2' => 'Heslo:',
	'login_preferez_refuser' => '<b>Ak radšej odmietate cookies,</b> máte k dispozícii iný, menej bezpečný, spôsob:',
	'login_recharger' => 'obnoviť túto stránku',
	'login_rester_identifie' => 'Pamätať si moje ID niekoľko dní',
	'login_retour_public' => 'Späť na verejne prístupnú stránku',
	'login_retour_site' => 'Späť na verejne prístupnú stránku',
	'login_retoursitepublic' => 'Späť na verejne prístupnú stránku',
	'login_sans_cookie' => 'Identifikácia bez cookie',
	'login_securise' => 'Zabezpečené prihlásenie',
	'login_sinscrire' => 'Zaregistrovať sa',
	'login_test_navigateur' => 'Testuje sa prehliadač/nové pripojenie',
	'login_verifiez_navigateur' => '(Skontrolujte však, či si prehliadač nezapamätal vaše heslo.)',

	// M
	'masquer_colonne' => 'Schovať tento stĺpec',
	'masquer_trad' => 'Schovať preklady',
	'module_fichiers_langues' => 'Jazykové súbory',

	// N
	'navigateur_pas_redirige' => 'Ak vás nepresmeruje prehliadač, kliknite sem, aby ste mohli pokračovať.',
	'numero' => 'Číslo',

	// O
	'occurence' => 'Výskyt',
	'onglet_affacer_base' => 'Vymazať databázu',
	'onglet_auteur' => 'Autor',
	'onglet_contenu_site' => 'Obsah stránok',
	'onglet_evolution_visite_mod' => 'Úroveň návštev',
	'onglet_fonctions_avances' => 'Funkcie pre pokročilych',
	'onglet_informations_personnelles' => 'Osobné údaje',
	'onglet_interactivite' => 'Interaktivita',
	'onglet_messagerie' => 'Odkazovač',
	'onglet_repartition_rubrique' => 'Početnosť podľa rubrík',
	'onglet_save_restaur_base' => 'Zálohovať/obnoviť databázu',
	'onglet_vider_cache' => 'Vyprázdniť cache',

	// P
	'pass_choix_pass' => 'Prosím, zvoľte si nové heslo:',
	'pass_erreur' => 'Chyba',
	'pass_erreur_acces_refuse' => '<b>Chyba:</b> k tejto stránke už viac nemáte prístup.',
	'pass_erreur_code_inconnu' => '<b>Chyba:</b> tento kód sa nezhoduje s kódom žiadneho návštevníka s prístupovými právami na túto stránku.',
	'pass_erreur_non_enregistre' => '<b>Chyba:</b> adresa <tt>@email_oubli@</tt> nie je zaregistrovaná na tejto stránke.',
	'pass_erreur_non_valide' => '<b>Chyba:</b> e-mail <tt>@email_oubli@</tt> nie je platný!',
	'pass_erreur_probleme_technique' => '<b>Chyba:</b> tento e-mail sa nepodarilo poslať kvôli technickému problému.',
	'pass_espace_prive_bla' => 'Súkromná zóna tejto stránky je
 pre návštevníkov prístupná po registrácii. Keď sa zaregistrujete,
budete si môcť prezerať články, ktoré sa
 upravujú, posielať články a diskutovať na diskusných fórach.',
	'pass_forum_bla' => 'Požiadali ste o účasť v diskusnom fóre
vyhradenom pre zaregistrovaných návštevníkov.',
	'pass_indiquez_cidessous' => 'Zadajte e-mailovú adresu, s ktorou ste sa
 predtým zaregistrovali.
Dostanete e-mail, ktorý vám vysvetlí, ako si
môžete obnoviť svoje heslo.',
	'pass_mail_passcookie' => '(Toto je automatická správa)

Ak si chcete obnoviť prístup na stránku
@nom_site_spip@ (@adresse_site@)

prosím, choďte na túto adresu:
    @sendcookie@

Potom môžete zadať nové heslo
a znova sa prihlásiť na stránku.
',
	'pass_mot_oublie' => 'Zabudnuté heslo',
	'pass_nouveau_enregistre' => 'Vaše nové heslo bolo uložené.',
	'pass_nouveau_pass' => 'Nové heslo',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Zabudnuté heslo',
	'pass_procedure_changer' => 'Ak si chcete zmeniť heslo, musíme overiť vašu identitu. Použijeme na to e-mailovú adresu priradenú k vášmu účtu.', # MODIF
	'pass_quitter_fenetre' => 'Zatvoriť toto okno',
	'pass_rappel_login' => 'Na pripomenutie: váš identifikátor (prihlasovacie meno) je "@login@".',
	'pass_recevoir_mail' => 'Dostanete e-mail, ktorý vám vysvetlí, ako znova získať prístup na stránku.',
	'pass_retour_public' => 'Späť na verejne prístupnú stránku',
	'pass_rien_a_faire_ici' => 'Niet tu čo robiť.',
	'pass_vousinscrire' => 'Registrácia na stránke',
	'precedent' => 'Predchádz.',
	'previsualisation' => 'Ukážka',
	'previsualiser' => 'Zobraziť ukážku',

	// R
	'retour' => 'Návrat',

	// S
	'spip_conforme_dtd' => 'Podľa SPIPu sa táto stránka zhoduje so svojím DOCTYPEOM:',
	'squelette' => 'Šablóna',
	'squelette_inclus_ligne' => 'vložená šablóna, riadok',
	'squelette_ligne' => 'šablóna, riadok',
	'stats_visites_et_popularite' => '@visites@ návštev, popularita: @popularite@',
	'suivant' => 'Ďalej',

	// T
	'taille_go' => '@taille@ Gb',
	'taille_ko' => '@taille@ kB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ byteov',
	'texte_actualite_site_1' => 'Keď sa zoznámite s rozhraním, kliknite na «',
	'texte_actualite_site_2' => 'úplné rozhranie',
	'texte_actualite_site_3' => '» aby ste mali k dispozícií viac funkcií.',
	'texte_creation_automatique_vignette' => 'Automatické vytváranie ukážok miniatúr je na tejto stránke povolené. Ak prostredníctvom tohto formulára nainštalujete obrázky vo formáte (-och) @gd_formats@, budú doplnené miniatúrou s maximálnou veľkosťou @taille_preview@ pixelov.',
	'texte_documents_associes' => 'Tieto súbory sú k článku priradené,
    ale neboli doň priamo
    vložené. V závislosti od vzhľadu verejne prístupnej stránky
    by sa mohli zobraziť ako pripojené súbory.',
	'texte_erreur_mise_niveau_base' => 'Chyba databázy počas aktualizácie.
      Obrázok <b>@fichier@</b> neprešiel (článok @id_article@).<p>
   Dobre si prečítajte tento oznam, skúste vykonať aktualizáciu zvnova
   a potom skontrolovať, či sa obrázky v článkoch
      stále objavujú.',
	'texte_erreur_visiteur' => 'Pokúsili ste sa vojsť do súkromnej zóny pomocou oprávneného používateľského mena.',
	'texte_inc_auth_1' => 'Prihlásili ste sa ako
  <b>@auth_login@,</b> ale toto používateľské meno v databáze neexistuje.
',
	'texte_inc_auth_2' => 'Znova sa pripojiť',
	'texte_inc_auth_3' => ', skončite, a ak treba,
  reštartujte svoj prehliadač.',
	'texte_inc_config' => 'Zmeny vykonané v nastave­niach týchto stránok majú veľký vplyv
  na fungovanie stránky. Odporúča sa nerobiť zmeny, ak neviete,
 ako SPIP funguje. <br /><br /><b>
 Vo všeobecnosti sa veľmi odporúča
 nechať tieto zmeny na hlavného webmastera stránky.</b>',
	'texte_inc_meta_1' => 'Pri pokuse o zápis do súboru <code>@fichier@</code> nastala chyba. Ako administrátor, prosím,',
	'texte_inc_meta_2' => 'skontrolujte právo zápisu',
	'texte_inc_meta_3' => 'u priečinka <code>@repertoire@.</code>',
	'texte_statut_en_cours_redaction' => 'upravuje sa',
	'texte_statut_poubelle' => 'do koša',
	'texte_statut_propose_evaluation' => 'odoslaný na schválenie',
	'texte_statut_publie' => 'publikovaný online',
	'texte_statut_refuse' => 'zamietnutý',
	'titre_ajouter_mot_cle' => 'PRIDAŤ KĽÚČOVÉ SLOVO:',
	'titre_cadre_raccourcis' => 'SKRATKY:',
	'titre_changer_couleur_interface' => 'Zmena farby rozhrania',
	'titre_image_admin_article' => 'Môžete upravovať tento článok',
	'titre_image_administrateur' => 'Administrátor',
	'titre_image_aide' => 'Pomoc k tomuto prvku',
	'titre_image_auteur_supprime' => 'Odstránený autor',
	'titre_image_redacteur' => 'Redaktor bez prístupu',
	'titre_image_redacteur_02' => 'Redaktor',
	'titre_image_selecteur' => 'Zobraziť zoznam',
	'titre_image_visiteur' => 'Návštevník',
	'titre_joindre_document' => 'PRIPOJIŤ DOKUMENT',
	'titre_mots_cles' => 'KĽÚČOVÉ SLOVÁ',
	'titre_probleme_technique' => 'Varovanie: technický problém (so SQL serverom) bráni v prístupe k tejto časti stránky. Ďakujeme vám za trpezlivosť.',
	'titre_publier_document' => 'PUBLIKOVAŤ DOKUMENT V TEJTO RUBRIKE',
	'titre_signatures_attente' => 'Podpisy čakajúce na overenie',
	'titre_signatures_confirmees' => 'Potvrdené podpisy',
	'titre_statistiques' => 'Štatistiky stránok',
	'titre_titre_document' => 'Názov dokumentu:',
	'todo' => 'nasleduje',
	'trad_definir_reference' => 'Vybrať "@titre@" ako referenciu pre preklady',
	'trad_reference' => '(referencia pre preklady)',

	// Z
	'zbug_balise_b_aval' => ': tag B je v cykle príliš neskoro',
	'zbug_balise_inexistante' => 'Tag @balise@ je zle deklarovaný pre @from@',
	'zbug_balise_sans_argument' => 'V tagu @balise@ chýba parameter',
	'zbug_boucle' => 'cyklus',
	'zbug_boucle_recursive_undef' => 'nedefinovaný rekurzívny cyklus: @nom@',
	'zbug_calcul' => 'Výpočet',
	'zbug_champ_hors_boucle' => 'Pole @champ@ mimo cyklu',
	'zbug_champ_hors_motif' => 'Pole @champ@ mimo kontextu @motif@',
	'zbug_code' => 'kód',
	'zbug_critere_inconnu' => 'neznáme kritérium @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} v tabuľke bez je­di­neč­né­ho pri­már­ne­ho kľúča',
	'zbug_distant_interdit' => 'Externé dáta sú zakázané',
	'zbug_doublon_table_sans_cle_primaire' => 'V tabuľke, ktorá nemá jednoduchý primárny kľúč, sú duplicitné položky',
	'zbug_doublon_table_sans_index' => 'Duplicitné údaje v tabuľke bez indexu',
	'zbug_erreur_boucle_double' => 'Duplicitná definícia cyklu @id@',
	'zbug_erreur_boucle_fermant' => 'Cyklus @id@ nie je uzavretý',
	'zbug_erreur_boucle_syntaxe' => 'Syntax cyklu @id@ nie je správna',
	'zbug_erreur_compilation' => 'Chyba pri kompilácii',
	'zbug_erreur_execution_page' => 'Chyba pri vykonávaní',
	'zbug_erreur_filtre' => 'Nezadefinovaný filter @filtre@',
	'zbug_erreur_meme_parent' => 'Kritérium {meme_parent} platí iba pre cykly (DISKUSNÉ FÓRA) alebo (RUBRIKY)',
	'zbug_erreur_squelette' => 'Chyba (-y) v šablóne',
	'zbug_hors_compilation' => 'Neskompilované',
	'zbug_info_erreur_squelette' => 'Chyba na stránke',
	'zbug_inversion_ordre_inexistant' => 'Zrušenie neexistujúceho poradia',
	'zbug_pagination_sans_critere' => 'Tag #PAGINATION (stránkovanie) nemá kritérium {pagination} alebo sa používa v rekurzívnom cykle',
	'zbug_parametres_inclus_incorrects' => 'Nesprávny parameter zaradenia: @param@',
	'zbug_profile' => 'Čas prepočítania: @time@',
	'zbug_resultat' => 'výsledok',
	'zbug_serveur_indefini' => 'Neuvedený server SQL',
	'zbug_statistiques' => 'Požiadavka na štatistiku SQL podľa trvania',
	'zbug_table_inconnue' => 'Neznáma tabuľka SQL "@table@"',
	'zxml_connus_attributs' => 'známe atribúty',
	'zxml_de' => 'od',
	'zxml_inconnu_attribut' => 'neznámy atribút',
	'zxml_inconnu_balise' => 'neznámy tag',
	'zxml_inconnu_entite' => 'neznáma entita',
	'zxml_inconnu_id' => 'neznáme ID',
	'zxml_mais_de' => 'ale od',
	'zxml_non_conforme' => 'nepravda podľa zásady',
	'zxml_non_fils' => 'nie je podradené',
	'zxml_nonvide_balise' => 'tag nie je prázdny',
	'zxml_obligatoire_attribut' => 'vyžaduje sa atribút, ktorý chýba v',
	'zxml_succession_fils_incorrecte' => 'nesprávne dedenie podradenosti',
	'zxml_survoler' => 'Ak chcete vidieť správne, prejdite kurzorom',
	'zxml_valeur_attribut' => 'hodnota atribútu',
	'zxml_vide_balise' => 'prázdny tag',
	'zxml_vu' => 'zobrazené predtým'
);

?>
